@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 #
 # Copyright 2002-2006 Zuza Software Foundation
 #
@@ -43,7 +41,7 @@ def is_css_entity(entity):
     return False
 
 
-class dtd2po(object):
+class dtd2po:
 
     def __init__(self, blankmsgstr=False, duplicatestyle="msgctxt"):
         self.currentgroup = None
