@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2002-2013 Zuza Software Foundation
 #
@@ -27,7 +26,7 @@ from translate.convert import convert
 from translate.storage import php, po
 
 
-class php2po(object):
+class php2po:
     """Convert one or two PHP files to a single PO file."""
 
     SourceStoreClass = php.phpfile
