@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2014 Zuza Software Foundation
 #
@@ -22,7 +21,6 @@ strings in the IDML template. It creates a new IDML file using the translations
 of the PO file.
 """
 
-import six
 from io import BytesIO
 from zipfile import ZIP_DEFLATED, ZipFile
 
@@ -30,8 +28,8 @@ import lxml.etree as etree
 
 from translate.convert import convert
 from translate.storage import factory
-from translate.storage.idml import (NO_TRANSLATE_ELEMENTS,
-                                    INLINE_ELEMENTS, copy_idml, open_idml)
+from translate.storage.idml import (INLINE_ELEMENTS, NO_TRANSLATE_ELEMENTS,
+                                    copy_idml, open_idml)
 from translate.storage.xml_extract.extract import (ParseState,
                                                    process_idml_translatable)
 from translate.storage.xml_extract.generate import (apply_translations,
@@ -50,7 +48,7 @@ def translate_idml(template, input_file, translatable_files):
         idml_data = open_idml(template)
         parser = etree.XMLParser(strip_cdata=False, resolve_entities=False)
         return dict((filename, etree.fromstring(data, parser).getroottree())
-                    for filename, data in six.iteritems(idml_data))
+                    for filename, data in idml_data.items())
 
     def load_unit_tree(input_file):
         """Return a dict with the translations grouped by files IDML package.
@@ -122,7 +120,7 @@ def translate_idml(template, input_file, translatable_files):
 
         make_parse_state = lambda: ParseState(NO_TRANSLATE_ELEMENTS,
                                               INLINE_ELEMENTS)
-        for filename, dom_tree in six.iteritems(dom_trees):
+        for filename, dom_tree in dom_trees.items():
             file_unit_tree = unit_trees[filename]
             apply_translations(dom_tree.getroot(), file_unit_tree,
                                replace_dom_text(make_parse_state,
@@ -143,7 +141,7 @@ def write_idml(template_zip, output_file, dom_trees):
     output_zip = copy_idml(template_zip, output_zip, dom_trees.keys())
 
     # Replace the translated files in the IDML package.
-    for filename, dom_tree in six.iteritems(dom_trees):
+    for filename, dom_tree in dom_trees.items():
         output_zip.writestr(filename, etree.tostring(dom_tree,
                                                      encoding='UTF-8',
                                                      xml_declaration=True,
