@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2004-2006 Zuza Software Foundation
 #
@@ -29,7 +28,7 @@ from translate.convert import convert
 from translate.storage import factory
 
 
-class po2txt(object):
+class po2txt:
     """po2txt can take a po file and generate txt.
 
     best to give it a template file otherwise will just concat msgstrs
