@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2004-2010 Zuza Software Foundation
 #
@@ -23,9 +22,7 @@ files, preserving existing translations.
 See: http://docs.translatehouse.org/projects/translate-toolkit/en/latest/commands/pot2po.html
 for examples and usage instructions.
 """
-from __future__ import unicode_literals
 
-import six
 
 from translate.misc.multistring import multistring
 from translate.search import match
@@ -123,9 +120,11 @@ def _store_pre_merge(input_store, output_store, template_store, **kwargs):
     if isinstance(input_store, poheader.poheader):
         _do_poheaders(input_store, output_store, template_store)
     elif isinstance(input_store, catkeys.CatkeysFile):
-        #FIXME: shouldn't we be merging template_store.header instead?
         #FIXME: also this should be a format specific hook
-        output_store.header = input_store.header
+        if template_store is not None:
+            output_store.header = template_store.header
+        else:
+            output_store.header = input_store.header
 
     # Dispatch to format specific functions
     store_pre_merge_hook = "_store_pre_merge_%s" % input_store.__class__.__name__
@@ -203,7 +202,7 @@ def _do_poheaders(input_store, output_store, template_store):
 
     if template_store is not None and isinstance(template_store, poheader.poheader):
         templateheadervalues = template_store.parseheader()
-        for key, value in six.iteritems(templateheadervalues):
+        for key, value in templateheadervalues.items():
             if key == "Project-Id-Version":
                 project_id_version = value
             elif key == "Last-Translator":
@@ -225,7 +224,7 @@ def _do_poheaders(input_store, output_store, template_store):
                 kwargs[key] = value
 
     inputheadervalues = input_store.parseheader()
-    for key, value in six.iteritems(inputheadervalues):
+    for key, value in inputheadervalues.items():
         if key in ("Project-Id-Version", "Last-Translator", "Language-Team",
                    "PO-Revision-Date", "Content-Type",
                    "Content-Transfer-Encoding", "Plural-Forms"):
