@@ -1,5 +1,7 @@
+
+from io import BytesIO
+
 from translate.convert import csv2po, test_convert
-from translate.misc import wStringIO
 from translate.storage import csvl10n, po
 from translate.storage.test_base import first_translatable, headerless_len
 
@@ -11,14 +13,14 @@ def test_replacestrings():
                                  ("two", "twee")) == "Test een twee three"
 
 
-class TestCSV2PO(object):
+class TestCSV2PO:
 
     def csv2po(self, csvsource, template=None):
         """helper that converts csv source to po source without requiring files"""
-        inputfile = wStringIO.StringIO(csvsource)
+        inputfile = BytesIO(csvsource.encode())
         inputcsv = csvl10n.csvfile(inputfile)
         if template:
-            templatefile = wStringIO.StringIO(template)
+            templatefile = BytesIO(template.encode())
             inputpot = po.pofile(templatefile)
         else:
             inputpot = None
@@ -87,7 +89,7 @@ wat lank aanhou"
         minicsv = r''',"Hello ""Everyone""","Good day ""All"""
 ,"Use \"".","Gebruik \""."'''
         print(minicsv)
-        csvfile = csvl10n.csvfile(wStringIO.StringIO(minicsv))
+        csvfile = csvl10n.csvfile(BytesIO(minicsv.encode()))
         print(bytes(csvfile))
         pofile = self.csv2po(minicsv)
         unit = first_translatable(pofile)
@@ -123,6 +125,14 @@ msgstr ""
         assert pounit.source == "Source"
         assert pounit.target == "Target"
 
+    def test_escaped_newlines(self):
+        """Tests that things keep working with escaped newlines"""
+        minicsv = '"source","target"\r\n"yellow pencil","żółty\\nołówek"'
+        pofile = self.csv2po(minicsv)
+        assert pofile.findunit("yellow pencil") is not None
+        assert pofile.findunit("yellow pencil").target == "żółty\\nołówek"
+        assert headerless_len(pofile.units) == 1
+
 
 class TestCSV2POCommand(test_convert.TestConvertCommand, TestCSV2PO):
     """Tests running actual csv2po commands on files"""
