@@ -1,18 +1,15 @@
-# -*- coding: utf-8 -*-
 
-from __future__ import unicode_literals
+from io import BytesIO
 
 from pytest import importorskip, raises
 
 from translate.convert import po2ini, test_convert
-from translate.misc import wStringIO
-from translate.storage import po
 
 
 importorskip("iniparse")
 
 
-class TestPO2Ini(object):
+class TestPO2Ini:
 
     ConverterClass = po2ini.po2ini
 
@@ -20,11 +17,11 @@ class TestPO2Ini(object):
                  output_threshold=None, dialect="default",
                  success_expected=True):
         """Helper that converts to target format without using files."""
-        input_file = wStringIO.StringIO(input_string)
-        output_file = wStringIO.StringIO()
+        input_file = BytesIO(input_string.encode())
+        output_file = BytesIO()
         template_file = None
         if template_string:
-            template_file = wStringIO.StringIO(template_string)
+            template_file = BytesIO(template_string.encode())
         expected_result = 1 if success_expected else 0
         converter = self.ConverterClass(input_file, output_file, template_file,
                                         include_fuzzy, output_threshold,
