@@ -1,17 +1,14 @@
-# -*- coding: utf-8 -*-
-import sys
+from io import BytesIO
 
 from translate.convert import po2json
-from translate.misc import wStringIO
 from translate.storage import po
 
 
-class TestPO2JSON(object):
+class TestPO2JSON:
 
     def po2json(self, po_source, json_template):
         """helper that converts po source to json source without requiring files"""
-        input_file = wStringIO.StringIO(po_source)
-        json_file = wStringIO.StringIO(json_template)
+        input_file = BytesIO(po_source.encode())
         input_po = po.pofile(input_file)
         convertor = po2json.rejson(json_template, input_po)
         output_json = convertor.convertstore()
@@ -20,7 +17,7 @@ class TestPO2JSON(object):
     def test_basic(self):
         """test a basic po to json conversion"""
         json_template = '''{ "text": "A simple string"}'''
-        input_po = u'''#: .text
+        input_po = '''#: .text
 msgid "A simple string"
 msgstr "Du texte simple"
 '''
