@@ -1,18 +1,15 @@
-# -*- coding: utf-8 -*-
+
+from io import BytesIO
 
 from translate.convert import po2web2py
-from translate.misc import wStringIO
 from translate.storage import po
 
-import six
-import pytest
 
-
-class TestPO2WEB2PY(object):
+class TestPO2WEB2PY:
 
     def po2web2py(self, po_source):
         """helper that converts po source to web2py source without requiring files"""
-        input_file = wStringIO.StringIO(po_source)
+        input_file = BytesIO(po_source.encode())
         input_po = po.pofile(input_file)
         convertor = po2web2py.po2pydict()
         output_web2py = convertor.convertstore(input_po, False)
@@ -32,7 +29,6 @@ msgstr "Du texte simple"
         web2py_out = self.po2web2py(input_po)
         assert web2py_out == expected_web2py
 
-    @pytest.mark.skipif(six.PY2, reason='Skipping unicode tests on PY2')
     def test_unicode(self):
         """test a po to web2py conversion with unicode"""
         input_po = '''#: .text
