@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2015 Zuza Software Foundation
 # Copyright 2015 Sarah Hale
@@ -20,14 +19,15 @@
 
 """ Tests converting .Net Resource (.resx) to Gettext PO localisation files """
 
-from translate.convert import test_convert, resx2po
-from translate.misc import wStringIO
+from io import BytesIO
+
+from translate.convert import resx2po, test_convert
 from translate.storage import po, resx
 from translate.storage.poheader import poheader
 from translate.storage.test_base import headerless_len
 
 
-class TestRESX2PO(object):
+class TestRESX2PO:
     target_filetype = po.pofile
     XMLskeleton = '''<?xml version="1.0" encoding="utf-8"?>
     <root>
@@ -89,7 +89,7 @@ class TestRESX2PO(object):
 
     def resx2po(self, resxsource, template=None, filter=None):
         """ Helper that converts resx source to po source without requiring files """
-        inputfile = wStringIO.StringIO(resxsource)
+        inputfile = BytesIO(resxsource.encode())
         inputresx = resx.RESXFile(inputfile)
         convertor = resx2po.resx2po()
         outputpo = convertor.convert_store(inputresx)
@@ -134,8 +134,8 @@ msgstr ""
         po_result = self.resx2po(resx_source)
 
         assert len(po_result.units) == 3
-        assert po_result.units[1].getnotes("developer") == u"This is a comment"
-        assert po_result.units[2].getnotes("developer") == u""
+        assert po_result.units[1].getnotes("developer") == "This is a comment"
+        assert po_result.units[2].getnotes("developer") == ""
 
     def test_translatorcomments(self):
         """ Tests translator comments """
@@ -150,10 +150,10 @@ msgstr ""
         po_result = self.resx2po(resx_source)
 
         assert len(po_result.units) == 3
-        assert po_result.units[1].getnotes("developer") == u"This is a developer comment"
-        assert po_result.units[1].getnotes("translator") == u"This is a translator comment"
-        assert po_result.units[2].getnotes("developer") == u""
-        assert po_result.units[2].getnotes("translator") == u""
+        assert po_result.units[1].getnotes("developer") == "This is a developer comment"
+        assert po_result.units[1].getnotes("translator") == "This is a translator comment"
+        assert po_result.units[2].getnotes("developer") == ""
+        assert po_result.units[2].getnotes("translator") == ""
 
     def test_locations(self):
         """ Tests location comments (#:) """
@@ -206,8 +206,8 @@ class TestRESX2POCommand(test_convert.TestConvertCommand, TestRESX2PO):
         po_result = po.pofile(self.open_testfile("simple.pot"))
         po_element = self.single_element(po_result)
 
-        assert po_element.source == u"A simple string"
-        assert po_element.target == u""
+        assert po_element.source == "A simple string"
+        assert po_element.target == ""
 
     def test_simple_po(self):
         """ Tests the simplest possible conversion to a po file """
@@ -234,4 +234,4 @@ class TestRESX2POCommand(test_convert.TestConvertCommand, TestRESX2PO):
         po_result = self.target_filetype(self.open_testfile("simple.po"))
 
         assert len(po_result.units) == 2
-        assert po_result.units[1].source == u"A simple string"
+        assert po_result.units[1].source == "A simple string"
