@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2004-2008,2010-2011 Zuza Software Foundation
 #
@@ -25,7 +24,6 @@ for examples and usage instructions.
 
 import logging
 import os
-import six
 import time
 
 from translate.filters import autocorrect, checks, pofilter
@@ -35,7 +33,7 @@ from translate.storage import factory, oo
 logger = logging.getLogger(__name__)
 
 
-class reoo(object):
+class reoo:
 
     def __init__(self, templatefile, languages=None, timestamp=None, includefuzzy=False, long_keys=False, filteraction="exclude"):
         """construct a reoo converter for the specified languages (timestamp=0 means leave unchanged)"""
@@ -57,7 +55,7 @@ class reoo(object):
     def makeindex(self):
         """makes an index of the oo keys that are used in the source file"""
         self.index = {}
-        for ookey, theoo in six.iteritems(self.o.ookeys):
+        for ookey, theoo in self.o.ookeys.items():
             sourcekey = oo.makekey(ookey, self.long_keys)
             self.index[sourcekey] = theoo
 
@@ -91,7 +89,7 @@ class reoo(object):
                                key, len(self.index))
                 try:
                     sourceunitlines = str(unit)
-                    if isinstance(sourceunitlines, six.text_type):
+                    if isinstance(sourceunitlines, str):
                         sourceunitlines = sourceunitlines.encode("utf-8")
                     logger.warning(sourceunitlines)
                 except Exception:
@@ -116,12 +114,11 @@ class reoo(object):
                 makecopy = True
         if makecopy:
             part2 = oo.ooline(part1.getparts())
-        unquotedid = unit.source
         unquotedstr = unit.target
         # If there is no translation, we don't want to add a line
         if len(unquotedstr.strip()) == 0:
             return
-        if isinstance(unquotedstr, six.text_type):
+        if isinstance(unquotedstr, str):
             unquotedstr = unquotedstr.encode("UTF-8")
         # finally set the new definition in the oo, but not if its empty
         if len(unquotedstr) > 0:
@@ -160,7 +157,7 @@ class oocheckfilter(pofilter.pocheckfilter):
         filterresult = self.filterunit(unit)
         if filterresult:
             if filterresult != autocorrect:
-                for filtername, filtermessage in six.iteritems(filterresult):
+                for filtername, filtermessage in filterresult.items():
                     location = unit.getlocations()[0]
                     if filtername in self.options.error:
                         logger.error("Error at %s::%s: %s",
@@ -173,7 +170,7 @@ class oocheckfilter(pofilter.pocheckfilter):
         return True
 
 
-class oofilteroptions(object):
+class oofilteroptions:
     error = ['variables', 'xmltags', 'escapes']
     warning = ['blank']
     #To only issue warnings for tests listed in warning, change the following to False:
@@ -224,6 +221,8 @@ def main(argv=None):
         ("po", "oo"): ("oo", convertoo),
         ("xlf", "oo"): ("oo", convertoo),
         ("xlf", "sdf"): ("sdf", convertoo),
+        ("xliff", "oo"): ("oo", convertoo),
+        ("xliff", "sdf"): ("sdf", convertoo),
     }
     # always treat the input as an archive unless it is a directory
     archiveformats = {(None, "output"): oo.oomultifile, (None, "template"): oo.oomultifile}
