@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2008 Zuza Software Foundation
 #
@@ -20,7 +19,6 @@
 """This module represents the Finnish language.
 """
 
-from __future__ import unicode_literals
 
 from translate.lang import common
 
