@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2010 Zuza Software Foundation
 #
@@ -22,6 +21,7 @@
 .. seealso:: http://en.wikipedia.org/wiki/Punjabi_language
 """
 
+
 import re
 
 from translate.lang import common
@@ -30,7 +30,7 @@ from translate.lang import common
 class pa(common.Common):
     """This class represents Punjabi."""
 
-    sentenceend = u"।!?…"
+    sentenceend = "।!?…"
 
     sentencere = re.compile(r"""(?s)    # make . also match newlines
                             .*?         # anything, but match non-greedy
@@ -41,8 +41,8 @@ class pa(common.Common):
                             """ % sentenceend, re.VERBOSE)
 
     puncdict = {
-        u". ": u"। ",
-        u".\n": u"।\n",
+        ". ": "। ",
+        ".\n": "।\n",
     }
 
     ignoretests = {
