@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2017 Zuza Software Foundation
 #
@@ -22,7 +21,6 @@
 .. seealso:: https://en.wikipedia.org/wiki/Polish_language
 """
 
-from __future__ import unicode_literals
 
 from translate.lang import common
 
