@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2009 Zuza Software Foundation
 #
@@ -25,7 +24,6 @@
    (v1.4.2) to ensure that we match currently released versions of Poedit.
 """
 
-from __future__ import unicode_literals
 
 lang_codes = {
     "aa": "Afar",
