@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2016 Zuza Software Foundation
 #
@@ -22,7 +21,6 @@
 .. seealso:: https://en.wikipedia.org/wiki/Brazilian_Portuguese
 """
 
-from __future__ import unicode_literals
 
 from translate.lang.common import Common
 
