@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2007-2017 Zuza Software Foundation
 #
@@ -22,7 +21,6 @@
 .. seealso:: http://en.wikipedia.org/wiki/Romanian_language
 """
 
-from __future__ import unicode_literals
 
 from translate.filters.checks import FilterFailure, TranslationChecker
 from translate.filters.decorators import cosmetic
