@@ -1,7 +1,5 @@
-#!/usr/bin/env python2
-# -*- coding: utf-8 -*-
 #
-# Copyright 2010 Zuza Software Foundation
+# Copyright 2010, 2016 Zuza Software Foundation
 #
 # This file is part of Virtaal.
 #
@@ -23,10 +21,13 @@
 .. seealso:: http://en.wikipedia.org/wiki/Tamil_language
 """
 
+
 from translate.lang import common
 
 
 class ta(common.Common):
     """This class represents Tamil."""
 
-    ignoretests = ["startcaps", "simplecaps"]
+    ignoretests = {
+        'all': ["simplecaps", "startcaps"],
+    }
