@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2014 Zuza Software Foundation
 #
@@ -16,15 +15,10 @@
 # You should have received a copy of the GNU General Public License along with
 # this program; if not, see <http://www.gnu.org/licenses/>.
 
-import six
 import warnings
 from functools import wraps
 
 
-class RemovedInTTK2Warning(DeprecationWarning):
-    pass
-
-
 def deprecated(message=""):
     """Decorator that marks functions and methods as deprecated.
 
@@ -37,7 +31,7 @@ def deprecated(message=""):
             msg = message  # Hack to avoid UnboundLocalError.
             if msg:
                 msg = "\n" + msg
-            func_code = func.func_code if six.PY2 else func.__code__
+            func_code = func.__code__
             warnings.warn_explicit(
                 "Call to deprecated function {0}.{1}".format(func.__name__,
                                                              msg),
