@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2006 Zuza Software Foundation
 #
@@ -20,48 +19,23 @@
 """Supports a hybrid Unicode string that can also have a list of alternate
 strings in the strings attribute
 """
-from __future__ import unicode_literals
-
-import warnings
-
-import six
-
-from .deprecation import RemovedInTTK2Warning
 
 
-def _create_text_type(newtype, string, encoding):
-    """Helper to construct a text type out of characters or bytes. Required to
-    temporarily preserve backwards compatibility. Must be removed in TTK2.
-    """
-    if string is None:
-        string = ''
-    if isinstance(string, six.text_type):
-        return six.text_type.__new__(newtype, string)
+class multistring(str):
 
-    warnings.warn(
-        'Passing non-ASCII bytes as well as the `encoding` argument to '
-        '`multistring` is deprecated. Always pass unicode characters instead.',
-        RemovedInTTK2Warning, stacklevel=2,
-    )
-    return six.text_type.__new__(newtype, string, encoding)
-
-
-class multistring(six.text_type):
-
-    def __new__(newtype, string=u"", *args, **kwargs):
-        encoding = kwargs.pop('encoding', 'utf-8')
+    def __new__(newtype, string=""):
         if isinstance(string, list):
             if not string:
                 raise ValueError("multistring must contain at least one string")
-            newstring = _create_text_type(newtype, string[0], encoding)
+            newstring = str.__new__(newtype, string[0])
             newstring.strings = [newstring] + [multistring.__new__(newtype, altstring) for altstring in string[1:]]
         else:
-            newstring = _create_text_type(newtype, string, encoding)
+            newstring = str.__new__(newtype, string)
             newstring.strings = [newstring]
         return newstring
 
     def __init__(self, *args, **kwargs):
-        super(multistring, self).__init__()
+        super().__init__()
         if not hasattr(self, "strings"):
             self.strings = []
 
@@ -70,13 +44,13 @@ class multistring(six.text_type):
             # Python 3 compatible cmp() equivalent
             return (s1 > s2) - (s1 < s2)
         if isinstance(otherstring, multistring):
-            parentcompare = cmp_compat(six.text_type(self), otherstring)
+            parentcompare = cmp_compat(str(self), otherstring)
             if parentcompare:
                 return parentcompare
             else:
                 return cmp_compat(self.strings[1:], otherstring.strings[1:])
-        elif isinstance(otherstring, six.text_type):
-            return cmp_compat(six.text_type(self), otherstring)
+        elif isinstance(otherstring, str):
+            return cmp_compat(str(self), otherstring)
         elif isinstance(otherstring, bytes):
             return cmp_compat(self.encode('utf-8'), otherstring)
         elif isinstance(otherstring, list) and otherstring:
@@ -94,21 +68,15 @@ class multistring(six.text_type):
         return self.__cmp__(otherstring) == 0
 
     def __repr__(self):
-        _repr = u"multistring(%r)" % (
-            [six.text_type(item) for item in self.strings]
+        return "multistring(%r)" % (
+            [str(item) for item in self.strings]
         )
-        return _repr.encode('utf-8') if six.PY2 else _repr
-
-    def __str__(self):
-        if six.PY2:
-            return self.encode('utf-8')
-        return super(multistring, self).__str__()
 
     def replace(self, old, new, count=None):
         if count is None:
-            newstr = multistring(super(multistring, self).replace(old, new))
+            newstr = multistring(super().replace(old, new))
         else:
-            newstr = multistring(super(multistring, self).replace(old, new, count))
+            newstr = multistring(super().replace(old, new, count))
         for s in self.strings[1:]:
             if count is None:
                 newstr.strings.append(s.replace(old, new))
