@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2004-2006 Zuza Software Foundation
 #
@@ -17,32 +16,17 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""A thin wrapper around BytesIO that accepts and auto-convert non bytes
-input
-"""
-
-import six
 from io import BytesIO
 
 
-class StringIO(BytesIO):
-
-    def __init__(self, buf=''):
-        if not isinstance(buf, six.string_types):
-            buf = bytes(buf)
-        if isinstance(buf, six.text_type):
-            buf = buf.encode('utf-8')
-        super(StringIO, self).__init__(buf)
-
-
-class CatchStringOutput(StringIO):
+class CatchStringOutput(BytesIO):
     """catches the output before it is closed and sends it to an onclose method
     """
 
     def __init__(self, onclose):
         """Set up the output stream, and remember a method to call on closing
         """
-        StringIO.__init__(self)
+        super().__init__()
         self.onclose = onclose
 
     def close(self):
@@ -51,7 +35,7 @@ class CatchStringOutput(StringIO):
         """
         value = self.getvalue()
         self.onclose(value)
-        super(CatchStringOutput, self).close()
+        super().close()
 
     def slam(self):
         """use this method to force the closing of the stream if it isn't
