@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2006-2009 Zuza Software Foundation
 #
@@ -23,9 +22,7 @@ units.
 
 import heapq
 import re
-import six
 from operator import itemgetter
-from six.moves import filter as ifilter
 
 from translate.misc.multistring import multistring
 from translate.search import lshtein, terminology
@@ -47,7 +44,7 @@ def _sort_matches(matches, match_info):
     matches.sort(key=lambda x: match_info[x.source]['pos'])
 
 
-class matcher(object):
+class matcher:
     """A class that will do matching and store configuration for the matching
     process.
     """
@@ -109,7 +106,7 @@ class matcher(object):
         """
         if isinstance(units, base.TranslationUnit):
             units = [units]
-        for candidate in ifilter(self.usable, units):
+        for candidate in (unit for unit in units if self.usable(unit)):
             simpleunit = base.TranslationUnit("")
             # We need to ensure that we don't pass multistrings futher, since
             # some modules (like the native Levenshtein) can't use it.
@@ -117,8 +114,8 @@ class matcher(object):
                 if len(candidate.source.strings) > 1:
                     simpleunit.orig_source = candidate.source
                     simpleunit.orig_target = candidate.target
-                simpleunit.source = six.text_type(candidate.source)
-                simpleunit.target = six.text_type(candidate.target)
+                simpleunit.source = str(candidate.source)
+                simpleunit.target = str(candidate.target)
             else:
                 simpleunit.source = candidate.source
                 simpleunit.target = candidate.target
@@ -239,14 +236,14 @@ class matcher(object):
 # The tuples define a regular expression to search for, and with what it
 # should be replaced.
 ignorepatterns = [
-    ("y\s*$", "ie"),          # category/categories, identify/identifies, apply/applied
-    ("[\s-]+", ""),           # down time / downtime, pre-order / preorder
+    (r"y\s*$", "ie"),          # category/categories, identify/identifies, apply/applied
+    (r"[\s-]+", ""),           # down time / downtime, pre-order / preorder
     ("-", " "),               # pre-order / pre order
     (" ", "-"),               # pre order / pre-order
 ]
 ignorepatterns_re = [(re.compile(a), b) for (a, b) in ignorepatterns]
 
-context_re = re.compile("\s+\(.*\)\s*$")
+context_re = re.compile(r"\s+\(.*\)\s*$")
 
 
 class terminologymatcher(matcher):
@@ -257,7 +254,7 @@ class terminologymatcher(matcher):
     def __init__(self, store, max_candidates=10, min_similarity=75, max_length=500, comparer=None):
         if comparer is None:
             comparer = terminology.TerminologyComparer(max_length)
-        matcher.__init__(self, store, max_candidates, min_similarity=10, max_length=max_length, comparer=comparer)
+        super().__init__(store, max_candidates, min_similarity=10, max_length=max_length, comparer=comparer)
         self.addpercentage = False
         self.match_info = {}
 
