@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2008-2010 Zuza Software Foundation
 #
@@ -23,22 +22,21 @@ clients using JSON over HTTP.
 
 import json
 import logging
-import six
 from argparse import ArgumentParser
 from io import BytesIO
-from six.moves.urllib import parse
+from urllib import parse
 
 from translate.misc import selector, wsgi
 from translate.storage import base, tmdb
 
 
-class TMServer(object):
+class TMServer:
     """A RESTful JSON TM server."""
 
     def __init__(self, tmdbfile, tmfiles, max_candidates=3, min_similarity=75,
                  max_length=1000, prefix="", source_lang=None,
                  target_lang=None):
-        if not isinstance(tmdbfile, six.text_type):
+        if not isinstance(tmdbfile, str):
             import sys
             tmdbfile = tmdbfile.decode(sys.getfilesystemencoding())
 
@@ -76,7 +74,7 @@ class TMServer(object):
     def translate_unit(self, environ, start_response, uid, slang, tlang):
         start_response("200 OK", [('Content-type', 'text/plain')])
         candidates = self.tmdb.translate_unit(uid, slang, tlang)
-        logging.debug("candidates: %s", six.text_type(candidates))
+        logging.debug("candidates: %s", str(candidates))
         response = json.dumps(candidates, indent=4).encode('utf-8')
         params = parse.parse_qs(environ.get('QUERY_STRING', ''))
         try:
@@ -112,7 +110,7 @@ class TMServer(object):
         start_response("200 OK", [('Content-type', 'text/plain')])
         #uid = unicode(urllib.unquote_plus(uid), "utf-8")
 
-        return [response]
+        return ["FIXME"]
 
     @selector.opliant
     def get_store_stats(self, environ, start_response, sid):
@@ -120,7 +118,7 @@ class TMServer(object):
         start_response("200 OK", [('Content-type', 'text/plain')])
         #sid = unicode(urllib.unquote_plus(sid), "utf-8")
 
-        return [response]
+        return ["FIXME"]
 
     @selector.opliant
     def upload_store(self, environ, start_response, sid, slang, tlang):
@@ -149,7 +147,7 @@ class TMServer(object):
         start_response("200 OK", [('Content-type', 'text/plain')])
         #sid = unicode(urllib.unquote_plus(sid), "utf-8")
 
-        return [response]
+        return ["FIXME"]
 
 
 def main():
