@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2006-2009 Zuza Software Foundation
 #
@@ -21,18 +20,14 @@
 
 import codecs
 import logging
-import six
-try:
-    import cPickle as pickle
-except ImportError:
-    import pickle
+import pickle
 from io import BytesIO
 
-from translate.misc.deprecation import deprecated
 from translate.misc.multistring import multistring
 from translate.storage.placeables import StringElem, parse as rich_parse
 from translate.storage.workflow import StateEnum as states
 
+
 # Simple BOM based encoding detection
 ENCODING_BOMS = (
     (codecs.BOM_UTF8, 'utf-8-sig'),
@@ -54,8 +49,7 @@ class ParseError(Exception):
         return repr(self.inner_exc)
 
 
-@six.python_2_unicode_compatible
-class TranslationUnit(object):
+class TranslationUnit:
     """Base class for translation units.
 
     Our concept of a *translation unit* is influenced heavily by `XLIFF
@@ -160,18 +154,18 @@ class TranslationUnit(object):
         >>> from translate.storage.placeables.interfaces import X
         >>> rich = [StringElem(['foo', X(id='xxx', sub=[' ']), 'bar'])]
         >>> TranslationUnit.rich_to_multistring(rich)
-        multistring(u'foo bar')
+        multistring('foo bar')
         """
-        return multistring([six.text_type(elem) for elem in elem_list])
+        return multistring([str(elem) for elem in elem_list])
 
     def multistring_to_rich(self, mulstring):
         """Convert a multistring to a list of "rich" string trees:
 
-        >>> target = multistring([u'foo', u'bar', u'baz'])
+        >>> target = multistring(['foo', 'bar', 'baz'])
         >>> TranslationUnit.multistring_to_rich(target)
-        [<StringElem([<StringElem([u'foo'])>])>,
-         <StringElem([<StringElem([u'bar'])>])>,
-         <StringElem([<StringElem([u'baz'])>])>]
+        [<StringElem([<StringElem(['foo'])>])>,
+         <StringElem([<StringElem(['bar'])>])>,
+         <StringElem([<StringElem(['baz'])>])>]
         """
         if isinstance(mulstring, multistring):
             return [rich_parse(s, self.rich_parsers) for s in mulstring.strings]
@@ -187,11 +181,6 @@ class TranslationUnit(object):
         self._rich_source = None
         self._source = source
 
-    # Deprecated on 2.3.1
-    @deprecated("Use `source` property instead")
-    def setsource(self, source):
-        self.source = source
-
     @property
     def target(self):
         return self._target
@@ -202,11 +191,6 @@ class TranslationUnit(object):
         self._rich_target = None
         self._target = target
 
-    # Deprecated on 2.3.1
-    @deprecated("Use `target` property instead")
-    def settarget(self, target):
-        self.target = target
-
     @property
     def rich_source(self):
         """
@@ -357,7 +341,7 @@ class TranslationUnit(object):
 
     def removenotes(self, origin=None):
         """Remove all the translator's notes."""
-        self.notes = u''
+        self.notes = ''
 
     def adderror(self, errorname, errortext):
         """Adds an error message to this unit.
@@ -485,7 +469,7 @@ class TranslationUnit(object):
     def get_state_id(self, n=None):
         if n is None:
             n = self.get_state_n()
-        for state_id, state_range in six.iteritems(self.STATE):
+        for state_id, state_range in self.STATE.items():
             if state_range[0] <= n < state_range[1]:
                 return state_id
         if self.STATE:
@@ -509,7 +493,7 @@ class TranslationUnit(object):
         pass
 
 
-class TranslationStore(object):
+class TranslationStore:
     """Base class for stores for multiple translation units of type UnitClass.
     """
 
@@ -730,13 +714,6 @@ class TranslationStore(object):
         odict['fileobj'] = None
         return odict
 
-    def __str__(self):
-        # This allows the old str(store) method for serialization to be kept
-        # for compatibility purpose.
-        if six.PY2:
-            return self.__bytes__()
-        return super(TranslationStore, self).__str__()
-
     def __bytes__(self):
         out = BytesIO()
         self.serialize(out)
@@ -774,7 +751,7 @@ class TranslationStore(object):
     def parsestring(cls, storestring):
         """Convert the string representation back to an object."""
         newstore = cls()
-        if isinstance(storestring, six.text_type):
+        if isinstance(storestring, str):
             # parse() is expecting bytes
             storestring = storestring.encode(cls.default_encoding)
         newstore.parse(storestring)
@@ -832,18 +809,18 @@ class TranslationStore(object):
             if encoding == self.encoding and suffix == 'sig':
                 encodings.append(detected_encoding['encoding'])
             elif detected_encoding['encoding'] != self.encoding:
-                logging.warn("trying to parse %s with encoding: %s but "
-                             "detected encoding is %s (confidence: %s)",
-                             self.filename, self.encoding,
-                             detected_encoding['encoding'],
-                             detected_encoding['confidence'])
+                logging.warning("trying to parse %s with encoding: %s but "
+                                "detected encoding is %s (confidence: %s)",
+                                self.filename, self.encoding,
+                                detected_encoding['encoding'],
+                                detected_encoding['confidence'])
             encodings.append(self.encoding)
         else:
             encodings.append(self.encoding)
 
         for encoding in encodings:
             try:
-                r_text = six.text_type(text, encoding)
+                r_text = str(text, encoding)
                 r_encoding = encoding
                 break
             except UnicodeDecodeError:
@@ -859,7 +836,7 @@ class TranslationStore(object):
 
     def savefile(self, storefile):
         """Write the string representation to the given file (or filename)."""
-        if isinstance(storefile, six.string_types):
+        if isinstance(storefile, str):
             storefile = open(storefile, 'wb')
         self.fileobj = storefile
         self._assignname()
@@ -887,7 +864,7 @@ class TranslationStore(object):
         """Reads the given file (or opens the given filename) and parses back
         to an object.
         """
-        if isinstance(storefile, six.string_types):
+        if isinstance(storefile, str):
             storefile = open(storefile, 'rb')
         mode = getattr(storefile, "mode", 'rb')
         #For some reason GzipFile returns 1, so we have to test for that here
