@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2006-2010 Zuza Software Foundation
 #
@@ -20,7 +19,8 @@
 """factory methods to build real storage objects that conform to base.py"""
 
 import os
-import six
+
+from translate.storage.base import TranslationStore
 
 
 #TODO: Monolingual formats (with template?)
@@ -31,7 +31,7 @@ decompressclass = {
 }
 
 
-classes_str = {
+_classes_str = {
     "csv": ("csvl10n", "csvfile"),
     "tab": ("omegat", "OmegaTFileTab"), "utf8": ("omegat", "OmegaTFile"),
     "po": ("po", "pofile"), "pot": ("po", "pofile"),
@@ -49,9 +49,6 @@ classes_str = {
     "ts": ("ts2", "tsfile"),
     "xliff": ("xliff", "xlifffile"), "xlf": ("xliff", "xlifffile"),
     "sdlxliff": ("xliff", "xlifffile"),
-
-    # Monolingual formats
-    "ftl": ("l20n", "l20nfile"),
 }
 ###  XXX:  if you add anything here, you must also add it to translate.storage.
 
@@ -64,7 +61,7 @@ _ext is a pseudo extension, that is their is no real extension by that name.
 
 def _examine_txt(storefile):
     """Determine the true filetype for a .txt file"""
-    if isinstance(storefile, six.string_types) and os.path.exists(storefile):
+    if isinstance(storefile, str) and os.path.exists(storefile):
         storefile = open(storefile, 'rb')
     try:
         start = storefile.read(600).strip()
@@ -87,7 +84,7 @@ def _examine_txt(storefile):
     return pseudo_extension
 
 
-hiddenclasses = {"txt": _examine_txt}
+_hiddenclasses = {"txt": _examine_txt}
 
 
 def _guessextention(storefile):
@@ -124,7 +121,7 @@ def _getname(storefile):
     """returns the filename"""
     if storefile is None:
         raise ValueError("This method cannot magically produce a filename when given None as input.")
-    if not isinstance(storefile, six.string_types):
+    if not isinstance(storefile, str):
         if not hasattr(storefile, "name"):
             storefilename = _getdummyname(storefile)
         else:
@@ -135,12 +132,16 @@ def _getname(storefile):
 
 
 def getclass(storefile, localfiletype=None, ignore=None, classes=None,
-             classes_str=classes_str, hiddenclasses=hiddenclasses):
+             classes_str=None, hiddenclasses=None):
     """Factory that returns the applicable class for the type of file
     presented.  Specify ignore to ignore some part at the back of the name
     (like .gz).
     """
     storefilename = _getname(storefile)
+    if classes_str is None:
+        classes_str = _classes_str
+    if hiddenclasses is None:
+        hiddenclasses = _hiddenclasses
     if ignore and storefilename.endswith(ignore):
         storefilename = storefilename[:-len(ignore)]
     ext = localfiletype
@@ -175,16 +176,21 @@ def getclass(storefile, localfiletype=None, ignore=None, classes=None,
 
 
 def getobject(storefile, localfiletype=None, ignore=None, classes=None,
-              classes_str=classes_str, hiddenclasses=hiddenclasses):
+              classes_str=None, hiddenclasses=None):
     """Factory that returns a usable object for the type of file presented.
 
-    :type storefile: file or str
+    :type storefile: file or str or TranslationStore
     :param storefile: File object or file name.
 
     Specify ignore to ignore some part at the back of the name (like .gz).
     """
-
-    if isinstance(storefile, six.string_types):
+    if isinstance(storefile, TranslationStore):
+        return storefile
+    if classes_str is None:
+        classes_str = _classes_str
+    if hiddenclasses is None:
+        hiddenclasses = _hiddenclasses
+    if isinstance(storefile, str):
         if os.path.isdir(storefile) or storefile.endswith(os.path.sep):
             from translate.storage import directory
             return directory.Directory(storefile)
