@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2008, 2011 Zuza Software Foundation
 #
@@ -26,7 +25,6 @@ See https://github.com/mozilla-l10n/langchecker/wiki/.lang-files-format for
 specifications on the format.
 """
 
-import six
 
 from translate.storage import base, txt
 
@@ -38,7 +36,6 @@ def strip_ok(string):
     return string
 
 
-@six.python_2_unicode_compatible
 class LangUnit(base.TranslationUnit):
     """This is just a normal unit with a weird string output"""
 
@@ -46,7 +43,7 @@ class LangUnit(base.TranslationUnit):
         self.locations = []
         self.eol = "\n"
         self.rawtarget = None
-        base.TranslationUnit.__init__(self, source)
+        super().__init__(source)
 
     def __str__(self):
         if self.istranslated():
@@ -66,9 +63,9 @@ class LangUnit(base.TranslationUnit):
                   else "# %s" % note)
                  for note
                  in self.getnotes('developer').split("\n")])
-            return u"%s%s;%s%s%s" % (
+            return "%s%s;%s%s%s" % (
                 notes, self.eol, self.source, self.eol, target)
-        return u";%s%s%s" % (self.source, self.eol, target)
+        return ";%s%s%s" % (self.source, self.eol, target)
 
     def getlocations(self):
         return self.locations
@@ -91,7 +88,7 @@ class LangStore(txt.TxtFile):
         self._headers = []
         self.eol = "\n"
         self.location_root = getattr(inputfile, "location_root", "")
-        super(LangStore, self).__init__(inputfile, **kwargs)
+        super().__init__(inputfile, **kwargs)
 
     def parse(self, lines):
         source_unit = None
@@ -156,10 +153,10 @@ class LangStore(txt.TxtFile):
             out.write(b"## active ##")
             out.write(eol)
         for header in self._headers:
-            out.write(six.text_type(header).encode('utf-8'))
+            out.write(str(header).encode('utf-8'))
             out.write(eol)
         for unit in self.units:
-            out.write(six.text_type(unit).encode('utf-8'))
+            out.write(str(unit).encode('utf-8'))
             out.write(eol * 3)
 
     def getlangheaders(self):
