@@ -1,5 +1,3 @@
-#!/usr/bin/env python2
-# -*- coding: utf-8 -*-
 #
 # Copyright 2009 Zuza Software Foundation
 # Copyright 2013-2014 F Wolff
@@ -32,7 +30,7 @@ class ElementNotFoundError(ValueError):
     pass
 
 
-class StringElem(object):
+class StringElem:
     """
     This class represents a sub-tree of a string parsed into a rich structure.
     It is also the base class of all placeables.
@@ -61,11 +59,11 @@ class StringElem(object):
     def __init__(self, sub=None, id=None, rid=None, xid=None, **kwargs):
         if sub is None:
             self.sub = []
-        elif isinstance(sub, (unicode, StringElem)):
+        elif isinstance(sub, (str, StringElem)):
             self.sub = [sub]
         else:
             for elem in sub:
-                if not isinstance(elem, (unicode, StringElem)):
+                if not isinstance(elem, (str, StringElem)):
                     raise ValueError(elem)
             self.sub = sub
             self.prune()
@@ -82,42 +80,44 @@ class StringElem(object):
     # SPECIAL METHODS #
     def __add__(self, rhs):
         """Emulate the ``unicode`` class."""
-        return unicode(self) + rhs
+        return str(self) + rhs
 
     def __contains__(self, item):
         """Emulate the ``unicode`` class."""
-        return item in unicode(self)
+        return item in str(self)
 
     def __eq__(self, rhs):
         """:returns: ``True`` if (and only if) all members as well as sub-trees
-            are equal. False otherwise."""
+        are equal. False otherwise.
+        """
         if not isinstance(rhs, StringElem):
             return False
 
-        return self.id == rhs.id and \
-               self.iseditable == rhs.iseditable and \
-               self.istranslatable == rhs.istranslatable and \
-               self.isvisible == rhs.isvisible and \
-               self.rid == rhs.rid and \
-               self.xid == rhs.xid and \
-               len(self.sub) == len(rhs.sub) and \
-               not [i for i in range(len(self.sub)) if self.sub[i] != rhs.sub[i]]
+        return (
+            self.id == rhs.id and
+            self.iseditable == rhs.iseditable and
+            self.istranslatable == rhs.istranslatable and
+            self.isvisible == rhs.isvisible and
+            self.rid == rhs.rid and
+            self.xid == rhs.xid and
+            len(self.sub) == len(rhs.sub) and
+            not [i for i in range(len(self.sub)) if self.sub[i] != rhs.sub[i]])
 
     def __ge__(self, rhs):
         """Emulate the ``unicode`` class."""
-        return unicode(self) >= rhs
+        return str(self) >= rhs
 
     def __getitem__(self, i):
         """Emulate the ``unicode`` class."""
-        return unicode(self)[i]
+        return str(self)[i]
 
     def __getslice__(self, i, j):
         """Emulate the ``unicode`` class."""
-        return unicode(self)[i:j]
+        return str(self)[i:j]
 
     def __gt__(self, rhs):
         """Emulate the ``unicode`` class."""
-        return unicode(self) > rhs
+        return str(self) > rhs
 
     def __iter__(self):
         """Create an iterator of this element's sub-elements."""
@@ -126,19 +126,19 @@ class StringElem(object):
 
     def __le__(self, rhs):
         """Emulate the ``unicode`` class."""
-        return unicode(self) <= rhs
+        return str(self) <= rhs
 
     def __len__(self):
         """Emulate the ``unicode`` class."""
-        return len(unicode(self))
+        return len(str(self))
 
     def __lt__(self, rhs):
         """Emulate the ``unicode`` class."""
-        return unicode(self) < rhs
+        return str(self) < rhs
 
     def __mul__(self, rhs):
         """Emulate the ``unicode`` class."""
-        return unicode(self) * rhs
+        return str(self) * rhs
 
     def __ne__(self, rhs):
         return not self.__eq__(rhs)
@@ -162,16 +162,11 @@ class StringElem(object):
         }
 
     def __str__(self):
-        if not self.isvisible:
-            return ''
-        return ''.join([unicode(elem).encode('utf-8') for elem in self.sub])
-
-    def __unicode__(self):
         if callable(self.renderer):
             return self.renderer(self)
         if not self.isvisible:
-            return u''
-        return u''.join([unicode(elem) for elem in self.sub])
+            return ''
+        return ''.join([str(elem) for elem in self.sub])
 
     # METHODS #
     def apply_to_strings(self, f):
@@ -182,14 +177,15 @@ class StringElem(object):
         """
         for elem in self.flatten():
             for i in range(len(elem.sub)):
-                if isinstance(elem.sub[i], basestring):
+                if isinstance(elem.sub[i], str):
                     elem.sub[i] = f(elem.sub[i])
 
     def copy(self):
         """Returns a copy of the sub-tree.  This should be overridden in
         sub-classes with more data.
 
-        .. note:: ``self.renderer`` is **not** copied."""
+        .. note:: ``self.renderer`` is **not** copied.
+        """
         #logging.debug('Copying instance of class %s' % (self.__class__.__name__))
         cp = self.__class__(id=self.id, xid=self.xid, rid=self.rid)
         for sub in self.sub:
@@ -222,11 +218,12 @@ class StringElem(object):
         Partial nodes will only be removed if they are editable.
 
         :returns: A ``StringElem`` representing the removed sub-string, the
-                  parent node from which it was deleted as well as the offset at
-                  which it was deleted from. ``None`` is returned for the parent
-                  value if the root was deleted. If the parent and offset values
-                  are not ``None``, ``parent.insert(offset, deleted)``
-                  effectively undoes the delete."""
+                  parent node from which it was deleted as well as the offset
+                  at which it was deleted from. ``None`` is returned for the
+                  parent value if the root was deleted. If the parent and
+                  offset values are not ``None``, ``parent.insert(offset,
+                  deleted)`` effectively undoes the delete.
+        """
         if start_index == end_index:
             return StringElem(), self, 0
         if start_index > end_index:
@@ -312,7 +309,7 @@ class StringElem(object):
 
             # XXX: This might not have the expected result if start['elem']
             # is a StringElem sub-class instance.
-            newstr = u''.join(start['elem'].sub)
+            newstr = ''.join(start['elem'].sub)
             removed = StringElem(newstr[start['offset']:end['offset']])
             newstr = newstr[:start['offset']] + newstr[end['offset']:]
             parent = self.get_parent_elem(start['elem'])
@@ -367,7 +364,7 @@ class StringElem(object):
         for node in marked_nodes:
             try:
                 self.delete_elem(node)
-            except ElementNotFoundError as e:
+            except ElementNotFoundError:
                 pass
 
         if start['elem'] is not end['elem']:
@@ -375,13 +372,13 @@ class StringElem(object):
                 (not start['elem'].iseditable and start['elem'].isfragile)):
                 self.delete_elem(start['elem'])
             elif start['elem'].iseditable:
-                start['elem'].sub = [u''.join(start['elem'].sub)[:start['offset']]]
+                start['elem'].sub = [''.join(start['elem'].sub)[:start['offset']]]
 
             if (end_offset + len(end['elem']) == end['index'] or
                 (not end['elem'].iseditable and end['elem'].isfragile)):
                 self.delete_elem(end['elem'])
             elif end['elem'].iseditable:
-                end['elem'].sub = [u''.join(end['elem'].sub)[end['offset']:]]
+                end['elem'].sub = [''.join(end['elem'].sub)[end['offset']:]]
 
         self.prune()
         return removed, None, None
@@ -400,12 +397,12 @@ class StringElem(object):
             if sub.isleaf() and filter(sub):
                 elems.append(sub)
             else:
-                elems.extend(sub.depth_first())
+                elems.extend(sub.depth_first(filter))
         return elems
 
     def encode(self, encoding=sys.getdefaultencoding()):
         """More ``unicode`` class emulation."""
-        return unicode(self).encode(encoding)
+        return str(self).encode(encoding)
 
     def elem_offset(self, elem):
         """Find the offset of ``elem`` in the current tree.
@@ -416,7 +413,8 @@ class StringElem(object):
         is used as replacement for this one.
 
         :returns: The string index where element ``e`` starts, or -1 if ``e``
-                  was not found."""
+                  was not found.
+        """
         offset = 0
         for e in self.iter_depth_first():
             if e is elem:
@@ -431,16 +429,17 @@ class StringElem(object):
             if e.isleaf():
                 leafoffset = 0
                 for s in e.sub:
-                    if unicode(s) == unicode(elem):
+                    if str(s) == str(elem):
                         return offset + leafoffset
                     else:
-                        leafoffset += len(unicode(s))
+                        leafoffset += len(str(s))
                 offset += len(e)
         return -1
 
     def elem_at_offset(self, offset):
         """Get the ``StringElem`` in the tree that contains the string rendered
-            at the given offset."""
+        at the given offset.
+        """
         if offset < 0 or offset > len(self):
             return None
 
@@ -454,21 +453,23 @@ class StringElem(object):
         return elem
 
     def find(self, x):
-        """Find sub-string ``x`` in this string tree and return the position
-            at which it starts."""
-        if isinstance(x, basestring):
-            return unicode(self).find(x)
+        """Find sub-string ``x`` in this string tree and return the position at
+        which it starts.
+        """
+        if isinstance(x, str):
+            return str(self).find(x)
         if isinstance(x, StringElem):
-            return unicode(self).find(unicode(x))
+            return str(self).find(str(x))
         return None
 
     def find_elems_with(self, x):
         """Find all elements in the current sub-tree containing ``x``."""
-        return [elem for elem in self.flatten() if x in unicode(elem)]
+        return [elem for elem in self.flatten() if x in str(elem)]
 
     def flatten(self, filter=None):
-        """Flatten the tree by returning a depth-first search over the
-        tree's leaves."""
+        """Flatten the tree by returning a depth-first search over the tree's
+        leaves.
+        """
         if filter is None or not callable(filter):
             filter = lambda e: True
         return [elem for elem in self.iter_depth_first(lambda e: e.isleaf() and filter(e))]
@@ -484,10 +485,10 @@ class StringElem(object):
 
         :returns: A dictionary with the following items:
 
-            * *elem*: The element in which ``index`` resides.
-            * *index*: Copy of the ``index`` parameter
-            * *offset*: The offset of ``index`` into ``'elem'``.
-         """
+           - *elem*: The element in which ``index`` resides.
+           - *index*: Copy of the ``index`` parameter
+           - *offset*: The offset of ``index`` into ``'elem'``.
+        """
         info = {
             'elem': self.elem_at_offset(index),
             'index': index,
@@ -504,7 +505,8 @@ class StringElem(object):
 
     def get_parent_elem(self, child):
         """Searches the current sub-tree for and returns the parent of the
-            ``child`` element."""
+        ``child`` element.
+        """
         for elem in self.iter_depth_first():
             if not isinstance(elem, StringElem):
                 continue
@@ -515,17 +517,18 @@ class StringElem(object):
 
     def insert(self, offset, text, preferred_parent=None):
         """Insert the given text at the specified offset of this string-tree's
-            string (Unicode) representation."""
+        string (Unicode) representation.
+        """
         if offset < 0 or offset > len(self):
             raise IndexError('Index out of range: %d' % (offset))
-        if isinstance(text, (str, unicode)):
+        if isinstance(text, str):
             text = StringElem(text)
         if not isinstance(text, StringElem):
             raise ValueError('text must be of type StringElem')
 
         def checkleaf(elem, text):
             if elem.isleaf() and type(text) is StringElem and text.isleaf():
-                return unicode(text)
+                return str(text)
             return text
 
         # There are 4 general cases (including specific cases) where text can
@@ -591,11 +594,11 @@ class StringElem(object):
                 #logging.debug('Case 3')
                 eoffset = offset - self.elem_offset(oelem)
                 if oelem.isleaf():
-                    s = unicode(oelem)  # Collapse all sibling strings into one
+                    s = str(oelem)  # Collapse all sibling strings into one
                     head = s[:eoffset]
                     tail = s[eoffset:]
                     if type(text) is StringElem and text.isleaf():
-                        oelem.sub = [head + unicode(text) + tail]
+                        oelem.sub = [head + str(text) + tail]
                     else:
                         oelem.sub = [StringElem(head), text, StringElem(tail)]
                     return True
@@ -667,7 +670,7 @@ class StringElem(object):
         return False
 
     def insert_between(self, left, right, text):
-        """Insert the given text between the two parameter ``StringElem``\s."""
+        r"""Insert the given text between the two parameter ``StringElem``\s."""
         if not isinstance(left, StringElem) and left is not None:
             raise ValueError('"left" is not a StringElem or None')
         if not isinstance(right, StringElem) and right is not None:
@@ -681,7 +684,7 @@ class StringElem(object):
                 raise ValueError('"left" and "right" refer to the same element and is not empty.')
             if not left.iseditable:
                 return False
-        if isinstance(text, unicode):
+        if isinstance(text, str):
             text = StringElem(text)
 
         if left is right:
@@ -783,7 +786,7 @@ class StringElem(object):
         :rtype: bool
         """
         for e in self.sub:
-            if not isinstance(e, (str, unicode)):
+            if not isinstance(e, str):
                 return False
         return True
 
@@ -804,7 +807,8 @@ class StringElem(object):
 
     def map(self, f, filter=None):
         """Apply ``f`` to all nodes for which ``filter`` returned ``True``
-        (optional)."""
+        (optional).
+        """
         if filter is not None and not callable(filter):
             raise ValueError('filter is not callable or None')
         if filter is None:
@@ -817,23 +821,25 @@ class StringElem(object):
     @classmethod
     def parse(cls, pstr):
         """Parse an instance of this class from the start of the given string.
-            This method should be implemented by any sub-class that wants to
-            parseable by :mod:`translate.storage.placeables.parse`.
+        This method should be implemented by any sub-class that wants to
+        parseable by :mod:`translate.storage.placeables.parse`.
 
-            :type  pstr: unicode
-            :param pstr: The string to parse into an instance of this class.
-            :returns: An instance of the current class, or ``None`` if the
-                string not parseable by this class."""
+        :type  pstr: unicode
+        :param pstr: The string to parse into an instance of this class.
+        :returns: An instance of the current class, or ``None`` if the string
+                  not parseable by this class.
+        """
         return cls(pstr)
 
     def print_tree(self, indent=0, verbose=False):
         """Print the tree from the current instance's point in an indented
-            manner."""
+        manner.
+        """
         indent_prefix = " " * indent * 2
-        out = (u"%s%s [%s]" % (indent_prefix, self.__class__.__name__,
-                               unicode(self))).encode('utf-8')
+        out = ("%s%s [%s]" % (indent_prefix, self.__class__.__name__,
+                              str(self))).encode('utf-8')
         if verbose:
-            out += u' ' + repr(self)
+            out += ' ' + repr(self)
 
         print(out)
 
@@ -841,8 +847,8 @@ class StringElem(object):
             if isinstance(elem, StringElem):
                 elem.print_tree(indent + 1, verbose=verbose)
             else:
-                print((u'%s%s[%s]' % (indent_prefix, indent_prefix,
-                                      elem)).encode('utf-8'))
+                print(('%s%s[%s]' % (indent_prefix, indent_prefix,
+                                     elem)).encode('utf-8'))
 
     def prune(self):
         """Remove unnecessary nodes to make the tree optimal."""
@@ -875,18 +881,18 @@ class StringElem(object):
 
             if type(elem) is StringElem and elem.isleaf():
                 # Collapse all strings in this leaf into one string.
-                elem.sub = [u''.join(elem.sub)]
+                elem.sub = [''.join(elem.sub)]
 
             for i in reversed(range(len(elem.sub))):
                 # Remove empty strings or StringElem nodes
                 # (but not StringElem sub-class instances, because they
                 # might contain important (non-rendered) data.
-                if (type(elem.sub[i]) in (StringElem, str, unicode) and
+                if ((type(elem.sub[i]) == StringElem or isinstance(elem.sub[i], str)) and
                     len(elem.sub[i]) == 0):
                     del elem.sub[i]
                     continue
 
-                if type(elem.sub[i]) in (str, unicode) and not elem.isleaf():
+                if isinstance(elem.sub[i], str) and not elem.isleaf():
                     elem.sub[i] = StringElem(elem.sub[i])
                     changed = True
 
@@ -916,9 +922,10 @@ class StringElem(object):
 
     # TODO: Write unit test for this method
     def remove_type(self, ptype):
-        """Replace nodes with type ``ptype`` with base ``StringElem``\s,
-        containing the same sub-elements. This is only applicable to
-        elements below the element tree root node."""
+        r"""Replace nodes with type ``ptype`` with base ``StringElem``\s,
+        containing the same sub-elements. This is only applicable to elements
+        below the element tree root node.
+        """
         for elem in self.iter_depth_first():
             if type(elem) is ptype:
                 parent = self.get_parent_elem(elem)
@@ -931,10 +938,10 @@ class StringElem(object):
                 )
 
     def translate(self):
-        """Transform the sub-tree according to some class-specific needs.
-            This method should be either overridden in implementing sub-classes
-            or dynamically replaced by specific applications.
+        """Transform the sub-tree according to some class-specific needs.  This
+        method should be either overridden in implementing sub-classes or
+        dynamically replaced by specific applications.
 
-            :returns: The transformed Unicode string representing the sub-tree.
-            """
+        :returns: The transformed Unicode string representing the sub-tree.
+        """
         return self.copy()
