@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2002-2011 Zuza Software Foundation
 #
@@ -20,7 +19,6 @@
 """class that handles all header functions for a header in a po file"""
 
 import re
-import six
 import time
 from collections import OrderedDict
 
@@ -48,8 +46,7 @@ def parseheaderstring(input):
         if not line or ":" not in line:
             continue
         key, value = line.split(":", 1)
-        #We don't want unicode keys
-        key = str(key.strip())
+        key = key.strip()
         headervalues[key] = value.strip()
     return headervalues
 
@@ -95,7 +92,7 @@ def update(existing, add=False, **kwargs):
             removed.append(key)
         elif add and key in fixedargs:
             headerargs[key] = fixedargs.pop(key)
-    for key, value in six.iteritems(existing):
+    for key, value in existing.items():
         if key not in removed:
             headerargs[key] = value
     if add:
@@ -104,7 +101,7 @@ def update(existing, add=False, **kwargs):
     return headerargs
 
 
-class poheader(object):
+class poheader:
     """This class implements functionality for manipulation of po file headers.
     This class is a mix-in class and useless on its own. It must be used from
     all classes which represent a po file
@@ -271,7 +268,7 @@ class poheader(object):
 
     def updateheaderplural(self, nplurals, plural):
         """Update the Plural-Form PO header."""
-        if isinstance(nplurals, six.string_types):
+        if isinstance(nplurals, str):
             nplurals = int(nplurals)
         self.updateheader(add=True, Plural_Forms="nplurals=%d; plural=%s;" % (nplurals, plural))
 
@@ -311,7 +308,7 @@ class poheader(object):
         :param lang: the new target language code
         :type lang: str
         """
-        if isinstance(lang, six.string_types) and len(lang) > 1:
+        if isinstance(lang, str) and len(lang) > 1:
             self.updateheader(add=True, Language=lang, X_Poedit_Language=None, X_Poedit_Country=None)
 
     def getprojectstyle(self):
@@ -382,7 +379,7 @@ class poheader(object):
         outcontrib = False
         for line in header.getnotes("translator").split('\n'):
             line = line.strip()
-            if line == u"FIRST AUTHOR <EMAIL@ADDRESS>, YEAR.":
+            if line == "FIRST AUTHOR <EMAIL@ADDRESS>, YEAR.":
                 incontrib = True
                 continue
             if author_re.match(line):
