@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2002-2009 Zuza Software Foundation
 # Copyright 2013 F Wolff
@@ -25,13 +24,11 @@ files (pofile).
 import copy
 import logging
 import re
-import six
 import textwrap
-from io import BytesIO
+from itertools import chain
 
 from translate.lang import data
 from translate.misc import quote
-from translate.misc.deprecation import deprecated
 from translate.misc.multistring import multistring
 from translate.storage import pocommon, poparser
 
@@ -89,31 +86,44 @@ def escapeforpo(line):
     for special_key in po_escape_map:
         special_locations.extend(quote.find_all(line, special_key))
     special_locations = sorted(dict.fromkeys(special_locations).keys())
-    escaped_line = ""
+    escaped_line = []
     last_location = 0
     for location in special_locations:
-        escaped_line += line[last_location:location]
-        escaped_line += po_escape_map[line[location:location+1]]
+        escaped_line.append(line[last_location:location])
+        escaped_line.append(po_escape_map[line[location:location+1]])
         last_location = location + 1
-    escaped_line += line[last_location:]
-    return escaped_line
+    escaped_line.append(line[last_location:])
+    return "".join(escaped_line)
 
 
 def unescapehandler(escape):
     return po_unescape_map.get(escape, escape)
 
 
-wrapper = textwrap.TextWrapper(
-    width=77, replace_whitespace=False, expand_tabs=False,
-    drop_whitespace=False)
-wrapper.wordsep_re = re.compile(
-    r'(\s+|'                                  # any whitespace
-    r'[a-z0-9A-Z_-]+/|'                       # nicely split long URLs
-    r'\w*\\.|'                                # any escape should not be split
-    r'[\w\!\'\&\.\,\?]+\s+|'                  # space should go with a word
-    r'[^\s\w]*\w+[a-zA-Z]-(?=\w+[a-zA-Z])|'   # hyphenated words
-    r'(?<=[\w\!\"\'\&\.\,\?])-{2,}(?=\w))')   # em-dash
-wrapper.wordsep_re_uni = re.compile(wrapper.wordsep_re.pattern, re.UNICODE)
+class PoWrapper(textwrap.TextWrapper):
+    wordsep_re = re.compile(
+        r'''
+            (
+            \s+|                                  # any whitespace
+            [a-z0-9A-Z_-]+/|                      # nicely split long URLs
+            \w*\\.\w*|                            # any escape should not be split
+            n(?=%)|                               # wrap insidide plural equation
+            \.(?=\w)|                             # full stop inside word
+            [\w\!\'\&\.\,\?=<>%]+\s+|             # space should go with a word
+            [^\s\w]*\w+[a-zA-Z]-(?=\w+[a-zA-Z])|  # hyphenated words
+            (?<=[\w\!\"\'\&\.\,\?])-{2,}(?=\w)    # em-dash
+            )
+        ''',
+        re.VERBOSE
+    )
+
+    def __init__(self, width=77, replace_whitespace=False, expand_tabs=False, drop_whitespace=False):
+        super().__init__(
+            width=width,
+            replace_whitespace=replace_whitespace,
+            expand_tabs=expand_tabs,
+            drop_whitespace=drop_whitespace,
+        )
 
 
 def quoteforpo(text, wrapper_obj=None):
@@ -122,45 +132,31 @@ def quoteforpo(text, wrapper_obj=None):
     if text is None:
         return []
     if wrapper_obj is None:
-        wrapper_obj = wrapper
+        wrapper_obj = PoWrapper()
     text = escapeforpo(text)
     if wrapper_obj.width == -1:
-        return [u'"%s"' % text]
-    lines = text.split(u"\\n")
+        return ['"%s"' % text]
+    lines = text.split("\\n")
     for i, l in enumerate(lines[:-1]):
-        lines[i] = l + u"\\n"
+        lines[i] = l + "\\n"
 
     polines = []
     len_lines = len(lines)
     if len_lines > 2 or (len_lines == 2 and lines[1]) or len(lines[0]) > wrapper_obj.width - 6:
-        polines.append(u'""')
+        polines.append('""')
     for line in lines:
         lns = wrapper_obj.wrap(line)
         for ln in lns:
-            polines.append(u'"%s"' % ln)
+            polines.append('"%s"' % ln)
     return polines
 
 
-@deprecated("Use pypo.unescape() instead")
-def extractpoline(line):
-    """Remove quote and unescape line from po file.
-
-    :param line: a quoted line from a po file (msgid or msgstr)
-
-    .. deprecated:: 1.10
-       Replaced by :func:`unescape`. :func:`extractpoline` is kept to allow
-       tests of correctness, and in case of external users.
-    """
-    extracted = quote.extractwithoutquotes(line, '"', '"', '\\', includeescapes=unescapehandler)[0]
-    return extracted
-
-
 def unescape(line):
     """Unescape the given line.
 
     Quotes on either side should already have been removed.
     """
-    escape_places = quote.find_all(line, u"\\")
+    escape_places = quote.find_all(line, "\\")
     if not escape_places:
         return line
 
@@ -175,21 +171,21 @@ def unescape(line):
         if true_escape:
             true_escape_places.append(escape_pos)
 
-    extracted = u""
+    extracted = []
     lastpos = 0
     for pos in true_escape_places:
         # everything leading up to the escape
-        extracted += line[lastpos:pos]
+        extracted.append(line[lastpos:pos])
         # the escaped sequence (consuming 2 characters)
-        extracted += unescapehandler(line[pos:pos+2])
+        extracted.append(unescapehandler(line[pos:pos+2]))
         lastpos = pos+2
 
-    extracted += line[lastpos:]
-    return extracted
+    extracted.append(line[lastpos:])
+    return "".join(extracted)
 
 
 def unquotefrompo(postr):
-    return u"".join([unescape(line[1:-1]) for line in postr])
+    return "".join([unescape(line[1:-1]) for line in postr])
 
 
 def is_null(lst):
@@ -201,11 +197,9 @@ def extractstr(string):
     right = string.rfind('"')
     if right > -1:
         return string[left:right+1]
-    else:
-        return string[left:] + '"'
+    return string[left:] + '"'
 
 
-@six.python_2_unicode_compatible
 class pounit(pocommon.pounit):
     # othercomments = []      #   # this is another comment
     # automaticcomments = []  #   #. comment extracted from the source code
@@ -235,7 +229,7 @@ class pounit(pocommon.pounit):
         self.msgid_pluralcomments = []
         self.msgid_plural = []
         self.msgstr = []
-        pocommon.pounit.__init__(self, source)
+        super().__init__(source)
 
     def _initallcomments(self, blankall=False):
         """Initialises allcomments"""
@@ -299,11 +293,6 @@ class pounit(pocommon.pounit):
         self._rich_source = None
         self.msgid, self.msgid_plural = self._set_source_vars(source)
 
-    # Deprecated on 2.3.1
-    @deprecated("Use `source` property instead")
-    def getsource(self):
-        return self.source
-
     def _get_prev_source(self):
         """Returns the unescaped msgid"""
         return self._get_source_vars(self.prev_msgid, self.prev_msgid_plural)
@@ -321,8 +310,7 @@ class pounit(pocommon.pounit):
         """Returns the unescaped msgstr"""
         if isinstance(self.msgstr, dict):
             return multistring(list(map(unquotefrompo, self.msgstr.values())))
-        else:
-            return unquotefrompo(self.msgstr)
+        return unquotefrompo(self.msgstr)
 
     @target.setter
     def target(self, target):
@@ -334,7 +322,7 @@ class pounit(pocommon.pounit):
         if self.hasplural():
             if isinstance(target, multistring):
                 target = target.strings
-            elif isinstance(target, six.string_types):
+            elif isinstance(target, str):
                 target = [target]
         elif isinstance(target, (dict, list)):
             if len(target) == 1:
@@ -347,15 +335,10 @@ class pounit(pocommon.pounit):
         if isinstance(target, list):
             self.msgstr = dict([(i, self.quote(target[i])) for i in range(len(target))])
         elif isinstance(target, dict):
-            self.msgstr = dict([(i, self.quote(targetstring)) for i, targetstring in six.iteritems(target)])
+            self.msgstr = dict([(i, self.quote(targetstring)) for i, targetstring in target.items()])
         else:
             self.msgstr = self.quote(target)
 
-    # Deprecated on 2.3.1
-    @deprecated("Use `target` property instead")
-    def gettarget(self):
-        return self.target
-
     def getalttrans(self):
         """Return a list of alternate units.
 
@@ -379,12 +362,12 @@ class pounit(pocommon.pounit):
         :param origin: programmer, developer, source code, translator or None
         """
         if origin is None:
-            comments = u"".join([comment[2:] for comment in self.othercomments])
-            comments += u"".join([comment[3:] for comment in self.automaticcomments])
+            comments = "".join([comment[2:] or "\n" for comment in self.othercomments])
+            comments += "".join([comment[3:] or "\n" for comment in self.automaticcomments])
         elif origin == "translator":
-            comments = u"".join([comment[2:] for comment in self.othercomments])
+            comments = "".join([comment[2:] or "\n" for comment in self.othercomments])
         elif origin in ["programmer", "developer", "source code"]:
-            comments = u"".join([comment[3:] for comment in self.automaticcomments])
+            comments = "".join([comment[3:] or "\n" for comment in self.automaticcomments])
         else:
             raise ValueError("Comment type not valid")
         # Let's drop the last newline
@@ -400,14 +383,16 @@ class pounit(pocommon.pounit):
             return
         text = data.forceunicode(text)
         commentlist = self.othercomments
-        linestart = "# "
+        linestart = "#"
         autocomments = False
         if origin in ["programmer", "developer", "source code"]:
             autocomments = True
             commentlist = self.automaticcomments
-            linestart = "#. "
-        text = text.split("\n")
-        newcomments = [linestart + line + "\n" for line in text]
+            linestart = "#."
+        newcomments = [
+            "".join((linestart, " " if line else "", line, "\n"))
+            for line in text.split("\n")
+        ]
         if position == "append":
             newcomments = commentlist + newcomments
         elif position == "prepend":
@@ -429,7 +414,7 @@ class pounit(pocommon.pounit):
         # self.__shallow__
         shallow = set(self.__shallow__)
         # Make deep copies of all members which are not in shallow
-        for key, value in six.iteritems(self.__dict__):
+        for key, value in self.__dict__.items():
             if key not in shallow:
                 setattr(new_unit, key, copy.deepcopy(value))
         # Make shallow copies of all members which are in shallow
@@ -447,15 +432,13 @@ class pounit(pocommon.pounit):
     def _msgidlen(self):
         if self.hasplural():
             return len(unquotefrompo(self.msgid)) + len(unquotefrompo(self.msgid_plural))
-        else:
-            return len(unquotefrompo(self.msgid))
+        return len(unquotefrompo(self.msgid))
 
     def _msgstrlen(self):
         if isinstance(self.msgstr, dict):
-            combinedstr = "\n".join(filter(None, [unquotefrompo(msgstr) for msgstr in six.itervalues(self.msgstr)]))
+            combinedstr = "\n".join(filter(None, [unquotefrompo(msgstr) for msgstr in self.msgstr.values()]))
             return len(combinedstr)
-        else:
-            return len(unquotefrompo(self.msgstr))
+        return len(unquotefrompo(self.msgstr))
 
     def merge(self, otherpo, overwrite=False, comments=True, authoritative=False):
         """Merges the otherpo (with the same msgid) into this one.
@@ -466,7 +449,7 @@ class pounit(pocommon.pounit):
 
         def mergelists(list1, list2, split=False):
             # Decode where necessary (either all bytestrings or all unicode)
-            if six.text_type in [type(item) for item in list2] + [type(item) for item in list1]:
+            if any(isinstance(item, str) for item in chain(list1, list2)):
                 for position, item in enumerate(list1):
                     if isinstance(item, bytes):
                         list1[position] = item.decode("utf-8")
@@ -507,7 +490,7 @@ class pounit(pocommon.pounit):
                         if item not in list1 or len(item) < 5:
                             list1.append(item)
         if not isinstance(otherpo, pounit):
-            super(pounit, self).merge(otherpo, overwrite, comments)
+            super().merge(otherpo, overwrite, comments)
             return
         if comments:
             mergelists(self.othercomments, otherpo.othercomments)
@@ -544,7 +527,7 @@ class pounit(pocommon.pounit):
                 and is_null(self.msgctxt))
 
     def isblank(self):
-        if self.isheader() or len(self.msgidcomments):
+        if self.isheader() or self.msgidcomments:
             return False
         if (self._msgidlen() == 0) and (self._msgstrlen() == 0) and (is_null(self.msgctxt)):
             return True
@@ -553,15 +536,21 @@ class pounit(pocommon.pounit):
         # Before, the equivalent of the following was the final return statement:
         # return len(self.source.strip()) == 0
 
-    def hastypecomment(self, typecomment):
+    def _extracttypecomment(self):
+        for tc in self.typecomments:
+            for flag in tc.split(","):
+                value = flag.strip()
+                if not value or value == '#':
+                    continue
+                yield value
+
+    def hastypecomment(self, typecomment, parsed=None):
         """Check whether the given type comment is present"""
         if not self.typecomments:
             return False
-        for tc in self.typecomments:
-            # check for word boundaries properly by using a regular expression
-            if re.search("\\b%s\\b" % typecomment, tc):
-                return True
-        return False
+        if not parsed:
+            parsed = self._extracttypecomment()
+        return typecomment in parsed
 
     def hasmarkedcomment(self, commentmarker):
         """Check whether the given comment marker is present.
@@ -578,8 +567,8 @@ class pounit(pocommon.pounit):
 
     def settypecomment(self, typecomment, present=True):
         """Alters whether a given typecomment is present"""
-        if self.hastypecomment(typecomment) != present:
-            typecomments = re.findall(r"\b[-\w]+\b", "\n".join(self.typecomments))
+        typecomments = list(self._extracttypecomment())
+        if self.hastypecomment(typecomment, typecomments) != present:
             if present:
                 typecomments.append(typecomment)
             else:
@@ -616,14 +605,14 @@ class pounit(pocommon.pounit):
 
     def makeobsolete(self):
         """Makes this unit obsolete"""
-        super(pounit, self).makeobsolete()
+        super().makeobsolete()
         self.obsolete = True
         self.sourcecomments = []
         self.automaticcomments = []
 
     def resurrect(self):
         """Makes an obsolete unit normal"""
-        super(pounit, self).resurrect()
+        super().resurrect()
         self.obsolete = False
 
     def hasplural(self):
@@ -637,21 +626,21 @@ class pounit(pocommon.pounit):
         if isinstance(partlines, dict):
             partkeys = sorted(partlines.keys())
             return "".join([self._getmsgpartstr("%s[%d]" % (partname, partkey), partlines[partkey], partcomments) for partkey in partkeys])
-        partstr = partname + " "
+        partstr = [partname, " "]
         partstartline = 0
-        if len(partlines) > 0 and len(partcomments) == 0:
-            partstr += partlines[0]
+        if partlines and not partcomments:
+            partstr.append(partlines[0])
             partstartline = 1
-        elif len(partcomments) > 0:
-            if len(partlines) > 0 and len(unquotefrompo(partlines[:1])) == 0:
+        elif partcomments:
+            if partlines and not unquotefrompo(partlines[:1]):
                 # if there is a blank leader line, it must come before the comment
-                partstr += partlines[0] + '\n'
+                partstr.extend((partlines[0], '\n'))
                 # but if the whole string is blank, leave it in
                 if len(partlines) > 1:
                     partstartline += 1
             else:
                 # All partcomments should start on a newline
-                partstr += '""\n'
+                partstr.append('""\n')
             # combine comments into one if more than one
             if len(partcomments) > 1:
                 combinedcomment = []
@@ -664,16 +653,23 @@ class pounit(pocommon.pounit):
                     #Before we used to strip. Necessary in some cases?
                     combinedcomment.append(comment)
                 partcomments = self.quote("_:%s" % "".join(combinedcomment))
+                # Strip heading empty line for multiline string, it was already added above
+                if partcomments[0] == '""':
+                    partcomments = partcomments[1:]
             # comments first, no blank leader line needed
-            partstr += "\n".join(partcomments)
-            partstr = quote.rstripeol(partstr)
+            partstr.append(quote.rstripeol("\n".join(partcomments)))
         else:
-            partstr += '""'
-        partstr += '\n'
+            partstr.append('""')
+        partstr.append('\n')
         # add the rest
+        previous = None
         for partline in partlines[partstartline:]:
-            partstr += partline + '\n'
-        return partstr
+            # Avoid duplicate empty lines
+            if previous == '""' and partline == '""':
+                continue
+            previous = partline
+            partstr.extend((partline, '\n'))
+        return "".join(partstr)
 
     def __str__(self):
         """Convert to a string."""
@@ -683,7 +679,7 @@ class pounit(pocommon.pounit):
         """return this po element as a string"""
 
         def add_prev_msgid_lines(lines, prefix, header, var):
-            if len(var) > 0:
+            if var:
                 lines.append("%s %s %s\n" % (prefix, header, var[0]))
                 lines.extend("%s %s\n" % (prefix, line) for line in var[1:])
 
@@ -708,24 +704,24 @@ class pounit(pocommon.pounit):
                 # We need to account for a multiline msgid or msgstr here
                 obsoletelines[index] = obsoleteline.replace('\n"', '\n#~ "')
             lines.extend(obsoletelines)
-            return u"".join(lines)
+            return "".join(lines)
         # if there's no msgid don't do msgid and string, unless we're the
         # header this will also discard any comments other than plain
         # othercomments...
         if is_null(self.msgid):
             if not (self.isheader() or self.getcontext() or self.sourcecomments):
-                return u"".join(lines)
+                return "".join(lines)
         lines.extend(self.automaticcomments)
         lines.extend(self.sourcecomments)
         lines.extend(self.typecomments)
         add_prev_msgid_info(lines, prefix="#|")
         if self.msgctxt:
-            lines.append(self._getmsgpartstr(u"msgctxt", self.msgctxt))
-        lines.append(self._getmsgpartstr(u"msgid", self.msgid, self.msgidcomments))
+            lines.append(self._getmsgpartstr("msgctxt", self.msgctxt))
+        lines.append(self._getmsgpartstr("msgid", self.msgid, self.msgidcomments))
         if self.msgid_plural or self.msgid_pluralcomments:
-            lines.append(self._getmsgpartstr(u"msgid_plural", self.msgid_plural, self.msgid_pluralcomments))
-        lines.append(self._getmsgpartstr(u"msgstr", self.msgstr))
-        postr = u"".join(lines)
+            lines.append(self._getmsgpartstr("msgid_plural", self.msgid_plural, self.msgid_pluralcomments))
+        lines.append(self._getmsgpartstr("msgstr", self.msgstr))
+        postr = "".join(lines)
         return postr
 
     def getlocations(self):
@@ -791,9 +787,9 @@ class pounit(pocommon.pounit):
 #        id = '\0'.join(self.source.strings)
         id = self.source
         if self.msgidcomments:
-            id = u"_: %s\n%s" % (context, id)
+            id = "_: %s\n%s" % (context, id)
         elif context:
-            id = u"%s\04%s" % (context, id)
+            id = "%s\04%s" % (context, id)
         return id
 
 
@@ -803,10 +799,11 @@ class pofile(pocommon.pofile):
     UnitClass = pounit
 
     def __init__(self, inputfile=None, width=None, **kwargs):
-        self.wrapper = copy.copy(wrapper)
+        wrapargs = {}
         if width is not None:
-            self.wrapper.width = width
-        super(pofile, self).__init__(inputfile, **kwargs)
+            wrapargs = {"width": width}
+        self.wrapper = PoWrapper(**wrapargs)
+        super().__init__(inputfile, **kwargs)
 
     def create_unit(self):
         return self.UnitClass(wrapper=self.wrapper)
@@ -885,7 +882,7 @@ class pofile(pocommon.pofile):
                 else:
                     at_start = False
                 out.write(unit._getoutput().encode(self.encoding))
-        except UnicodeEncodeError as e:
+        except UnicodeEncodeError:
             if self.encoding == 'utf-8':
                 raise
             self.updateheader(add=True, Content_Type="text/plain; charset=UTF-8")
@@ -897,7 +894,7 @@ class pofile(pocommon.pofile):
         """encode any unicode strings in lines in self.encoding"""
         newlines = []
         for line in lines:
-            if isinstance(line, six.text_type):
+            if isinstance(line, str):
                 line = line.encode(self.encoding)
             newlines.append(line)
         return newlines
@@ -922,4 +919,4 @@ class pofile(pocommon.pofile):
 
     def addunit(self, unit):
         unit.wrapper = self.wrapper
-        super(pofile, self).addunit(unit)
+        super().addunit(unit)
