@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2007 Zuza Software Foundation
 #
@@ -21,7 +20,6 @@
 
 """
 
-import six
 
 from translate.lang import factory
 
@@ -38,7 +36,7 @@ from translate.lang import factory
 # Consider providing quickstats
 
 
-class Statistics(object):
+class Statistics:
     """Manages statistics for storage objects."""
 
     def __init__(self, sourcelanguage='en', targetlanguage='en', checkerstyle=None):
@@ -139,12 +137,12 @@ class Statistics(object):
         #TODO: we don't handle checking plurals at all yet, as this is tricky...
         source = unit.source
         target = unit.target
-        if isinstance(source, bytes) and isinstance(target, six.text_type):
+        if isinstance(source, bytes) and isinstance(target, str):
             source = source.decode(getattr(unit, "encoding", "utf-8"))
         #TODO: decoding should not be done here
 #        checkresult = self.checker.run_filters(unit, source, target)
         checkresult = {}
-        for checkname, checkmessage in six.iteritems(checkresult):
+        for checkname, checkmessage in checkresult.items():
             classes.append("check-" + checkname)
         return classes
 
