@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2007-2010 Zuza Software Foundation
 #
@@ -25,11 +24,11 @@
 import logging
 import os.path
 import re
-import six
 import stat
 import sys
-from six.moves import _thread, UserDict
+from collections import UserDict
 from sqlite3 import dbapi2
+from threading import current_thread
 
 from translate import __version__ as toolkitversion
 from translate.lang.common import Common
@@ -41,7 +40,7 @@ from translate.storage.workflow import StateEnum
 logger = logging.getLogger(__name__)
 
 #kdepluralre = re.compile("^_n: ") #Restore this if you really need support for old kdeplurals
-brtagre = re.compile("<br\s*?/?>")
+brtagre = re.compile(r"<br\s*?/?>")
 # xmltagre is a direct copy of the from placeables/general.py
 xmltagre = re.compile(r'''
         <                         # start of opening tag
@@ -169,7 +168,7 @@ def statefordb(unit):
     return UNTRANSLATED
 
 
-class FileTotals(object):
+class FileTotals:
     keys = ['translatedsourcewords',
             'fuzzysourcewords',
             'untranslatedsourcewords',
@@ -280,7 +279,7 @@ def suggestion_filename(filename):
 
 
 # ALL PUBLICLY ACCESSIBLE METHODS MUST BE DECORATED WITH THE transaction DECORATOR.
-class StatsCache(object):
+class StatsCache:
     """An object instantiated as a singleton for each statsfile that provides
     access to the database cache from a pool of StatsCache objects.
     """
@@ -293,13 +292,13 @@ class StatsCache(object):
     """The current cursor"""
 
     def __new__(cls, statsfile=None):
-        current_thread = _thread.get_ident()
+        current_thread_ident = current_thread().ident
 
         def make_database(statsfile):
 
             def connect(cache):
                 # sqlite needs to get the name in utf-8 on all platforms
-                cache.con = dbapi2.connect(statsfile.encode('utf-8') if six.PY2 else statsfile)
+                cache.con = dbapi2.connect(statsfile)
                 cache.cur = cache.con.cursor()
 
             def clear_old_data(cache):
@@ -317,7 +316,7 @@ class StatsCache(object):
                 except dbapi2.OperationalError:
                     return False
 
-            cache = cls._caches.setdefault(current_thread, {})[statsfile] = object.__new__(cls)
+            cache = cls._caches.setdefault(current_thread_ident, {})[statsfile] = object.__new__(cls)
             connect(cache)
             if clear_old_data(cache):
                 connect(cache)
@@ -335,14 +334,14 @@ class StatsCache(object):
                 if not os.path.exists(cachedir):
                     os.mkdir(cachedir)
                 if isinstance(cachedir, bytes):
-                    cachedir = six.text_type(cachedir, sys.getfilesystemencoding())
-                cls.defaultfile = os.path.realpath(os.path.join(cachedir, u"stats.db"))
+                    cachedir = str(cachedir, sys.getfilesystemencoding())
+                cls.defaultfile = os.path.realpath(os.path.join(cachedir, "stats.db"))
             statsfile = cls.defaultfile
         else:
             statsfile = os.path.realpath(statsfile)
         # First see if a cache for this file already exists:
-        if current_thread in cls._caches and statsfile in cls._caches[current_thread]:
-            return cls._caches[current_thread][statsfile]
+        if current_thread_ident in cls._caches and statsfile in cls._caches[current_thread_ident]:
+            return cls._caches[current_thread_ident][statsfile]
         # No existing cache. Let's build a new one and keep a copy
         return make_database(statsfile)
 
@@ -407,7 +406,7 @@ class StatsCache(object):
         store can be a TranslationFile object or a callback that returns one.
         """
         if isinstance(filename, bytes):
-            filename = six.text_type(filename, sys.getfilesystemencoding())
+            filename = str(filename, sys.getfilesystemencoding())
         realpath = os.path.realpath(filename)
         self.cur.execute("""SELECT fileid, st_mtime, st_size FROM files
                 WHERE path=?;""", (realpath,))
@@ -529,7 +528,7 @@ class StatsCache(object):
                 if unitindex:
                     index = unitindex
                 failures = checker.run_filters(unit)
-                for checkname, checkmessage in six.iteritems(failures):
+                for checkname, checkmessage in failures.items():
                     unitvalues.append((index, fileid, configid, checkname, checkmessage))
                     errornames.append("check-" + checkname)
         checker.setsuggestionstore(None)
@@ -740,3 +739,9 @@ class StatsCache(object):
             stats["targetwordcount"].append(targetcount)
 
         return stats
+
+    def close(self):
+        for threads in self._caches.values():
+            for cache in threads.values():
+                cache.con.close()
+        self._caches = {}
