@@ -1,5 +1,3 @@
-import pytest
-import six
 from lxml import etree
 
 from translate.misc.xml_helpers import setXMLspace
@@ -55,32 +53,30 @@ class TestXLIFFUnit(test_base.TestTranslationUnit):
         Source: https://en.wikipedia.org/wiki/Valid_characters_in_XML#XML_1.0
         """
         # Unicode Character 'CHARACTER TABULATION' (U+0009)
-        self.unit.target = u'Een\t'
-        assert self.unit.target == u'Een\t'
+        self.unit.target = 'Een\t'
+        assert self.unit.target == 'Een\t'
         # Unicode Character 'LINE FEED (LF)' (U+000A)
-        self.unit.target = u'Een\n'
-        assert self.unit.target == u'Een\n'
+        self.unit.target = 'Een\n'
+        assert self.unit.target == 'Een\n'
         # Unicode Character 'CARRIAGE RETURN (CR)' (U+000D)
-        self.unit.target = u'Een\r'
-        assert self.unit.target == u'Een\r'
+        self.unit.target = 'Een\r'
+        assert self.unit.target == 'Een\r'
 
     def test_unaccepted_control_chars(self):
         """Tests we cannot assign the unaccepted control chars without escaping.
 
         Source: https://en.wikipedia.org/wiki/Valid_characters_in_XML#XML_1.0
         """
-        exc_msg = ("All strings must be XML compatible: Unicode or ASCII, no "
-                   "NULL bytes or control characters")
         for code in xliff.ASCII_CONTROL_CODES:
-            self.unit.target = u'Een&#x%s;' % code.lstrip('0') or '0'
-            assert self.unit.target == u'Een%s' % six.unichr(int(code, 16))
-            self.unit.target = u'Een%s' % six.unichr(int(code, 16))
-            assert self.unit.target == u'Een%s' % six.unichr(int(code, 16))
+            self.unit.target = 'Een&#x%s;' % code.lstrip('0') or '0'
+            assert self.unit.target == 'Een%s' % chr(int(code, 16))
+            self.unit.target = 'Een%s' % chr(int(code, 16))
+            assert self.unit.target == 'Een%s' % chr(int(code, 16))
 
     def test_unaccepted_control_chars_escapes_roundtrip(self):
         """Test control characters go ok on escaping roundtrip."""
         for code in xliff.ASCII_CONTROL_CODES:
-            special = u'Een%s' % six.unichr(int(code, 16))
+            special = 'Een%s' % chr(int(code, 16))
             self.unit.source = special
             print("unit.source:", repr(self.unit.source))
             print("special:", repr(special))
@@ -128,80 +124,80 @@ class TestXLIFFfile(test_base.TestTranslationStore):
 
     def test_rich_source(self):
         xlifffile = xliff.xlifffile()
-        xliffunit = xlifffile.addsourceunit(u'')
+        xliffunit = xlifffile.addsourceunit('')
 
         # Test 1
-        xliffunit.rich_source = [StringElem([u'foo', X(id='bar'), u'baz'])]
+        xliffunit.rich_source = [StringElem(['foo', X(id='bar'), 'baz'])]
         source_dom_node = xliffunit.getlanguageNode(None, 0)
         x_placeable = source_dom_node[0]
 
         assert source_dom_node.text == 'foo'
 
-        assert x_placeable.tag == u'x'
+        assert x_placeable.tag == 'x'
         assert x_placeable.attrib['id'] == 'bar'
         assert x_placeable.tail == 'baz'
 
         xliffunit.rich_source[0].print_tree(2)
         print(xliffunit.rich_source)
-        assert xliffunit.rich_source == [StringElem([StringElem(u'foo'), X(id='bar'), StringElem(u'baz')])]
+        assert xliffunit.rich_source == [StringElem([StringElem('foo'), X(id='bar'), StringElem('baz')])]
 
         # Test 2
-        xliffunit.rich_source = [StringElem([u'foo', u'baz', G(id='oof', sub=[G(id='zab', sub=[u'bar', u'rab'])])])]
+        xliffunit.rich_source = [StringElem(['foo', 'baz', G(id='oof', sub=[G(id='zab', sub=['bar', 'rab'])])])]
         source_dom_node = xliffunit.getlanguageNode(None, 0)
         g_placeable = source_dom_node[0]
         nested_g_placeable = g_placeable[0]
 
-        assert source_dom_node.text == u'foobaz'
+        assert source_dom_node.text == 'foobaz'
 
-        assert g_placeable.tag == u'g'
+        assert g_placeable.tag == 'g'
         assert g_placeable.text is None
-        assert g_placeable.attrib[u'id'] == u'oof'
+        assert g_placeable.attrib['id'] == 'oof'
         assert g_placeable.tail is None
 
-        assert nested_g_placeable.tag == u'g'
-        assert nested_g_placeable.text == u'barrab'
-        assert nested_g_placeable.attrib[u'id'] == u'zab'
+        assert nested_g_placeable.tag == 'g'
+        assert nested_g_placeable.text == 'barrab'
+        assert nested_g_placeable.attrib['id'] == 'zab'
         assert nested_g_placeable.tail is None
 
         rich_source = xliffunit.rich_source
         rich_source[0].print_tree(2)
-        assert rich_source == [StringElem([u'foobaz', G(id='oof', sub=[G(id='zab', sub=[u'barrab'])])])]
+        assert rich_source == [StringElem(['foobaz', G(id='oof', sub=[G(id='zab', sub=['barrab'])])])]
 
     def test_rich_target(self):
         xlifffile = xliff.xlifffile()
-        xliffunit = xlifffile.addsourceunit(u'')
+        xliffunit = xlifffile.addsourceunit('')
 
         # Test 1
-        xliffunit.set_rich_target([StringElem([u'foo', X(id='bar'), u'baz'])], u'fr')
+        xliffunit.set_rich_target([StringElem(['foo', X(id='bar'), 'baz'])], 'fr')
         target_dom_node = xliffunit.getlanguageNode(None, 1)
         x_placeable = target_dom_node[0]
 
         assert target_dom_node.text == 'foo'
-        assert x_placeable.tag == u'x'
+        assert x_placeable.tag == 'x'
         assert x_placeable.attrib['id'] == 'bar'
         assert x_placeable.tail == 'baz'
 
         # Test 2
-        xliffunit.set_rich_target([StringElem([u'foo', u'baz', G(id='oof', sub=[G(id='zab', sub=[u'bar', u'rab'])])])], u'fr')
+        xliffunit.set_rich_target([StringElem(['foo', 'baz', G(id='oof', sub=[G(id='zab', sub=['bar', 'rab'])])])], 'fr')
         target_dom_node = xliffunit.getlanguageNode(None, 1)
         g_placeable = target_dom_node[0]
         nested_g_placeable = g_placeable[0]
 
-        assert target_dom_node.text == u'foobaz'
+        assert target_dom_node.text == 'foobaz'
 
-        assert g_placeable.tag == u'g'
+        assert g_placeable.tag == 'g'
         print('g_placeable.text: %s (%s)' % (g_placeable.text, type(g_placeable.text)))
         assert g_placeable.text is None
-        assert g_placeable.attrib[u'id'] == u'oof'
+        assert g_placeable.attrib['id'] == 'oof'
         assert g_placeable.tail is None
 
-        assert nested_g_placeable.tag == u'g'
-        assert nested_g_placeable.text == u'barrab'
-        assert nested_g_placeable.attrib[u'id'] == u'zab'
+        assert nested_g_placeable.tag == 'g'
+        assert nested_g_placeable.text == 'barrab'
+        assert nested_g_placeable.attrib['id'] == 'zab'
         assert nested_g_placeable.tail is None
 
         xliffunit.rich_target[0].print_tree(2)
-        assert xliffunit.rich_target == [StringElem([u'foobaz', G(id='oof', sub=[G(id='zab', sub=[u'barrab'])])])]
+        assert xliffunit.rich_target == [StringElem(['foobaz', G(id='oof', sub=[G(id='zab', sub=['barrab'])])])]
 
     def test_source(self):
         xlifffile = xliff.xlifffile()
@@ -310,7 +306,7 @@ class TestXLIFFfile(test_base.TestTranslationStore):
         assert altformat.find("<source") < altformat.find("<target")
 
         # test that a new target is still before alt-trans (bug 1098)
-        unit.target = u"newester target"
+        unit.target = "newester target"
         unitformat = str(unit)
         print(unitformat)
         assert unitformat.find("<source") < unitformat.find("<target") < unitformat.find("<alt-trans")
@@ -321,7 +317,7 @@ class TestXLIFFfile(test_base.TestTranslationStore):
         unit.markfuzzy()
         assert not unit.isfuzzy()  # untranslated
         unit.target = "Konsep"
-        assert unit.isfuzzy()
+        assert not unit.isfuzzy()  # translated
         unit.markfuzzy()
         assert unit.isfuzzy()
         unit.markfuzzy(False)
@@ -439,3 +435,101 @@ class TestXLIFFfile(test_base.TestTranslationStore):
         assert xlifffile.units[0].source == ''
         assert xlifffile.units[1].istranslatable()
         assert xlifffile.units[1].source == '&'
+
+    def test_multiple_filenodes(self):
+        xlfsource = '''<?xml version="1.0" encoding="utf-8"?>
+<xliff version="1.1" xmlns="urn:oasis:names:tc:xliff:document:1.1">
+  <file original="file0" source-language="en" datatype="plaintext">
+    <body>
+      <trans-unit id="hello" approved="yes">
+        <source>Hello</source>
+      </trans-unit>
+    </body>
+  </file>
+  <file original="file1" source-language="en" datatype="plaintext">
+    <body>
+      <trans-unit id="world" approved="yes">
+        <source>World</source>
+      </trans-unit>
+    </body>
+  </file>
+</xliff>'''
+        xfile = xliff.xlifffile.parsestring(xlfsource)
+        assert len(xfile.units) == 2
+        assert xfile.units[0].getid() == "file0\x04hello"
+        assert xfile.units[1].getid() == "file1\x04world"
+        xunit = xliff.xlifffile.UnitClass(source="goodbye")
+        xunit.setid("file2\x04goodbye")
+        xfile.addunit(xunit)
+        assert xfile.units[2].getid() == "file2\x04goodbye"
+        # if there is no file set it will use the active context
+        xunit = xliff.xlifffile.UnitClass(source="lastfile")
+        xunit.setid("lastfile")
+        xfile.addunit(xunit)
+        assert xfile.units[3].getid() == "file2\x04lastfile"
+        newxfile = xliff.xlifffile()
+        newxfile.addunit(xfile.units[0])
+        newxfile.addunit(xfile.units[1])
+        assert newxfile.units[0].getid() == "file0\x04hello"
+        assert newxfile.units[1].getid() == "file1\x04world"
+        assert newxfile.getfilenode("file0") is not None
+        assert newxfile.getfilenode("file1") is not None
+        assert not newxfile.getfilenode("foo")
+
+    def test_indent(self):
+        xlfsource = b'''<?xml version='1.0' encoding='UTF-8'?>
+<xliff xmlns="urn:oasis:names:tc:xliff:document:1.1" version="1.1">
+  <file original="doc.txt" source-language="en-US">
+    <body>
+      <trans-unit id="1" xml:space="preserve">
+        <source>File</source>
+        <target/>
+      </trans-unit>
+    </body>
+  </file>
+</xliff>
+'''
+        xlfsourcenote = b'''<?xml version='1.0' encoding='UTF-8'?>
+<xliff xmlns="urn:oasis:names:tc:xliff:document:1.1" version="1.1">
+  <file original="doc.txt" source-language="en-US">
+    <body>
+      <trans-unit id="1" xml:space="preserve">
+        <source>File</source>
+        <target/>
+        <note>Test note</note>
+      </trans-unit>
+    </body>
+  </file>
+</xliff>
+'''
+        xfile = xliff.xlifffile.parsestring(xlfsource)
+        assert bytes(xfile) == xlfsource
+        xfile.units[0].addnote('Test note')
+        assert bytes(xfile) == xlfsourcenote
+
+    def test_add_target(self):
+        xlfsource = b'''<?xml version='1.0' encoding='UTF-8'?>
+<xliff xmlns="urn:oasis:names:tc:xliff:document:1.1" version="1.1">
+  <file original="doc.txt" source-language="en-US">
+    <body>
+      <trans-unit id="1" xml:space="preserve">
+      </trans-unit>
+    </body>
+  </file>
+</xliff>
+'''
+        xlftarget = '''<?xml version='1.0' encoding='UTF-8'?>
+<xliff xmlns="urn:oasis:names:tc:xliff:document:1.1" version="1.1">
+  <file original="doc.txt" source-language="en-US">
+    <body>
+      <trans-unit id="1" xml:space="preserve">
+      <target>Soubor</target>
+      </trans-unit>
+    </body>
+  </file>
+</xliff>
+'''
+        xfile = xliff.xlifffile.parsestring(xlfsource)
+        assert bytes(xfile) == xlfsource
+        xfile.units[0].rich_target = ["Soubor"]
+        assert bytes(xfile).decode('ascii') == xlftarget
