@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 #
 # This file is part of translate.
 #
@@ -24,7 +22,6 @@ for examples and usage instructions.
 import logging
 import os
 import re
-import six
 import sys
 from operator import itemgetter
 
@@ -42,7 +39,7 @@ def create_termunit(term, unit, targets, locations, sourcenotes, transnotes, fil
         termunit.merge(unit, overwrite=False, comments=False)
     if len(targets.keys()) > 1:
         txt = '; '.join(["%s {%s}" % (target, ', '.join(files))
-                         for target, files in six.iteritems(targets)])
+                         for target, files in targets.items()])
         if termunit.target.find('};') < 0:
             termunit.target = txt
             termunit.markfuzzy()
@@ -55,12 +52,12 @@ def create_termunit(term, unit, targets, locations, sourcenotes, transnotes, fil
         termunit.addnote(sourcenote, "developer")
     for transnote in transnotes:
         termunit.addnote(transnote, "translator")
-    for filename, count in six.iteritems(filecounts):
+    for filename, count in filecounts.items():
         termunit.addnote("(poterminology) %s (%d)\n" % (filename, count), 'translator')
     return termunit
 
 
-class TerminologyExtractor(object):
+class TerminologyExtractor:
 
     def __init__(self, foldtitle=True, ignorecase=False, accelchars="", termlength=3,
                  sourcelanguage="en", invert=False, stopfile=None):
@@ -241,7 +238,7 @@ class TerminologyExtractor(object):
         terms = {}
         locre = re.compile(r":[0-9]+$")
         logger.info("%d terms from %d units", len(self.glossary), self.units)
-        for term, translations in six.iteritems(self.glossary):
+        for term, translations in self.glossary.items():
             if len(translations) <= 1:
                 continue
             filecounts = {}
@@ -390,7 +387,7 @@ class TerminologyOptionParser(optrecurse.RecursiveOptionParser):
             self.usage = "%prog " + " ".join([self.getusagestring(option) for option in self.option_list]) + \
                 "\n  input directory is searched for PO files, terminology PO file is output file"
         else:
-            super(TerminologyOptionParser, self).set_usage(usage)
+            super().set_usage(usage)
 
     def run(self):
         """parses the arguments, and runs recursiveprocess with the resulting options"""
